/******************************************************************************/
/*  Virtual File System ZIP header file                                       */
/*     -   Fredrik Redgrd <mrfrippe@writeme.com>                             */
/******************************************************************************/
//
// Tools to load files from zip files
// NOTE: filenames are case sensitive
//

#ifndef _FILESYSTEM_H_INCLUDED
#define _FILESYSTEM_H_INCLUDED

////////////////////////////////////////////////////
// vfsGetFileSize
//
//   Search for filename in the packfiles
//   and return the file size if file is found
//   if no file is found, vfsGetFileSize returns 0.
//
unsigned long vfsGetFileSize( const char *filename );

////////////////////////////////////////////////////
// vfsLoadFileIntoBuffer
//
//   Reads the contents of the file into the buffer
//   return value is the number of bytes put into
//   the buffer.
//   If the function fails, it returns 0.
//
//   The buffer should allready be allocated, and 
//   buffersize should be how big the buffer is
//   vfsLoadFileIntoBuffer will try to fill the 
//   buffer.
//
unsigned long vfsLoadFileIntoBuffer( const char *filename, void *buffer, unsigned long buffer_size );

////////////////////////////////////////////////////
// vfsBootup
//
//   Initializes all internal structures.
//   call this before using any other VFS function.
//   If bootup is successfull, vfsBootup returns 1.
//
int vfsBootup();

////////////////////////////////////////////////////
// vfsShutdown
//
//   Frees all internally used memory, closes open
//   files etc.
//   Call this before closing the program
//
void vfsShutdown();

////////////////////////////////////////////////////
// vfsAddPackfileSearchDir
//
//   Initializes all packfiles in the specified dir
//   to be ready for file access
//   return value is the number of packfiles added
//
int vfsAddPackfileSearchDir( const char *path );

////////////////////////////////////////////////////
// vfsSetLooseFilesBaseDir
//
//   Initializes all packfiles in the specified dir
//   to be ready for file access
//   return value is the number of packfiles added
//
int vfsSetLooseFilesBaseDir( const char *path );

#endif //_FILESYSTEM_H_INCLUDED