/******************************************************************************/
/*  Virtual File System Test Program                                          */
/*     -   Fredrik Redgrd <mrfrippe@writeme.com>                             */
/******************************************************************************/

// 
// Using the VFS is very easy:
// 
// 1) vfsBootup();							- sets up some internal stuff
// 2) vfsAddPackfileSearchDir(...);			- search for zip files at this path
// 3) vfsSetLooseFilesBaseDir(...);			- optional, if you want to use loose files
// 4) vfsGetFileSize(...);					- tries to get the file size, use to allocate
//											  file buffer
// 5) vfsLoadFileIntoBuffer(...);			- fills the buffer with the buffer_size first bytes
//											  of the file
// 6) vfsShutdown();						- release memory, and close files
// 
// NOTE: Filenames are  case sensitive
//

#include "filesystem.h"

#include <string.h>//strrchr
#include <windows.h>//GetModuleFilename
#include <stdio.h>//printf

int main(int argc, char *argv[])
{
	vfsBootup();
	
	char dir[_MAX_PATH];
	GetModuleFileName(NULL, dir, 200);

	dir[(strrchr( dir, '\\' )-dir)+1] = 0; //skip filename

	vfsAddPackfileSearchDir(dir);
	vfsSetLooseFilesBaseDir(dir);

	unsigned long size = vfsGetFileSize("File.txt");
	if (!size)
	{
		printf(
			"File.txt was not found in any zip file in the same dir as this exe\n"
			"or as a loose file in the same dir as this exe\n"
			);
		return 1;
	}

	char *buffer = new char[size+1]; //make room for a null
	unsigned long realsize = vfsLoadFileIntoBuffer("File.txt", buffer, size+1);
	if (!realsize)
	{
		printf(
			"An error occured when trying to get file contents, zip file may be currupt\n"
			);
		return 1;
	}
	buffer[realsize] = 0;

	printf(
		"File contents found:\n"
		"--------------------------------------------------------------------------------\n"
		);
	printf("%s\n\n", buffer);


	vfsShutdown();
	return 0;
}